<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl" sourcelanguage="en">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>Kies een programma</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>Geïnstalleerde programma&apos;s</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>Aangepaste opdracht</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>Uit te voeren opdrachtregel:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="78"/>
        <source>Application name:</source>
        <translation>Programmanaam:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="62"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;Deze speciale codes kunt u op de opdrachtregel gebruiken:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: vertegenwoordigt een enkele bestandsnaam&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: vertegenwoordigt meerdere bestandsnamen&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: vertegenwoordigt een enkele uri van het bestand&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: vertegenwoordigt meerdere uri&apos;s&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="98"/>
        <source>Keep terminal window open after command execution</source>
        <translation>Terminalvenster niet sluiten na uitvoeren van opdrachtregel</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="88"/>
        <source>Execute in terminal emulator</source>
        <translation>Uitvoeren in terminalvenster</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>Gekozen programma instellen als standaard bij dit bestandstype</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>Bladwijzers aanpassen</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="49"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="54"/>
        <source>Location</source>
        <translation>Locatie</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="64"/>
        <source>&amp;Add Item</source>
        <translation>Item &amp;toevoegen</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="74"/>
        <source>&amp;Remove Item</source>
        <translation>Item ve&amp;rwijderen</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="20"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>Slepen-en-neerzetten gebruiken items te herordenen</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>Bestand uitvoeren</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="42"/>
        <source>&amp;Open</source>
        <translation>&amp;Openen</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="55"/>
        <source>E&amp;xecute</source>
        <translation>&amp;Uitvoeren</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="65"/>
        <source>Execute in &amp;Terminal</source>
        <translation>Uitvoeren in &amp;terminalvenster</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="88"/>
        <source>Cancel</source>
        <translation>Afbreken</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="102"/>
        <source>Remember for next files of this kind</source>
        <translation>Onthouden voor andere bestanden van dit type</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../filedialog.ui" line="22"/>
        <source>Path:</source>
        <translation>Locatie:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="65"/>
        <source>File name:</source>
        <translation>Bestandsnaam:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="85"/>
        <source>File type:</source>
        <translation>Bestandstype:</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../file-operation-dialog.ui" line="42"/>
        <source>Destination:</source>
        <translation>Doel:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="65"/>
        <source>Processing:</source>
        <translation>Bezig met:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="78"/>
        <source>Preparing...</source>
        <translation>Bezig met voorbereiden…</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="85"/>
        <source>Progress:</source>
        <translation>Voortgang:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="119"/>
        <source>Time remaining:</source>
        <translation>Resterende tijd:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="99"/>
        <source>Files processed:</source>
        <translation>Aantal verwerkte bestanden:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>Bestandseigenschappen</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="41"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>Locatie:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="132"/>
        <source>File type:</source>
        <translation>Bestandstype:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="155"/>
        <source>MIME type:</source>
        <translation>MIME-type:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="195"/>
        <source>File size:</source>
        <translation>Bestandsgrootte:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="218"/>
        <source>On-disk size:</source>
        <translation>Omvang op schijf:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="241"/>
        <source>Last modified:</source>
        <translation>Laatst gewijzigd:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="106"/>
        <source>Link target:</source>
        <translation>Linkdoel:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="178"/>
        <source>Open With:</source>
        <translation>Openen met:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="264"/>
        <source>Last accessed:</source>
        <translation>Laatst geopend:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="287"/>
        <source>Created:</source>
        <translation>Aangemaakt op:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="310"/>
        <source>Contains:</source>
        <translation>Bevat:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="330"/>
        <source>Emblem:</source>
        <translation>Embleem:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="342"/>
        <source>Choose emblem</source>
        <translation>Kies een embleem</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="361"/>
        <source>Clear emblem</source>
        <translation>Embleem verwijderen</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="397"/>
        <source>Device Usage:</source>
        <translation>Apparaatgebruik:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="424"/>
        <source>Permissions</source>
        <translation>Rechten</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="439"/>
        <source>Ownership</source>
        <translation>Eigendom</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="473"/>
        <location filename="../file-props.ui" line="528"/>
        <location filename="../file-props.ui" line="642"/>
        <source>Group:</source>
        <translation>Groep:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="457"/>
        <location filename="../file-props.ui" line="511"/>
        <location filename="../file-props.ui" line="590"/>
        <source>Owner:</source>
        <translation>Eigenaar:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="492"/>
        <source>Access Control</source>
        <translation>Toegangsbeheer</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="545"/>
        <location filename="../file-props.ui" line="694"/>
        <source>Other:</source>
        <translation>Overig:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="562"/>
        <source>Make the file executable</source>
        <translation>Bestand uitvoerbaar maken</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="603"/>
        <location filename="../file-props.ui" line="655"/>
        <location filename="../file-props.ui" line="707"/>
        <source>Read</source>
        <translation>Lezen</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="616"/>
        <location filename="../file-props.ui" line="668"/>
        <location filename="../file-props.ui" line="720"/>
        <source>Write</source>
        <translation>Schrijven</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="629"/>
        <location filename="../file-props.ui" line="681"/>
        <location filename="../file-props.ui" line="733"/>
        <source>Execute</source>
        <translation>Uitvoeren</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="749"/>
        <source>Sticky</source>
        <translation>Vastgemaakt</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="756"/>
        <source>SetUID</source>
        <translation>SetUID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="763"/>
        <source>SetGID</source>
        <translation>SetGID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="792"/>
        <source>Advanced Mode</source>
        <translation>Expertmodus</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../appchoosercombobox.cpp" line="66"/>
        <source>Customize</source>
        <translation>Aanpassen</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../appchooserdialog.cpp" line="268"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>Kies een programma om %1-bestanden mee te openen</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../createnewmenu.cpp" line="62"/>
        <source>Folder</source>
        <translation>Map</translation>
    </message>
    <message>
        <location filename="../createnewmenu.cpp" line="66"/>
        <source>Blank File</source>
        <translation>Leeg bestand</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../core/dirlistjob.cpp" line="48"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation>De opgegeven map, ‘%1’, is ongeldig</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="84"/>
        <source>Loading...</source>
        <translation>Bezig met laden…</translation>
    </message>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="267"/>
        <location filename="../dirtreemodelitem.cpp" line="311"/>
        <location filename="../dirtreemodelitem.cpp" line="409"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;geen onderliggende mappen&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../dirtreeview.cpp" line="217"/>
        <source>Open in New T&amp;ab</source>
        <translation>Openen op nieuw t&amp;abblad</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="221"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Openen in nieuw &amp;venster</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="226"/>
        <source>Open in Termina&amp;l</source>
        <translation>Openen in termina&amp;lvenster</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>Hierheen kopiëren</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>Hierheen verplaatsen</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>Snelkoppeling hier maken</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Afbreken</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cannot drop here</source>
        <translation>Hier kan niks worden geplaatst</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../editbookmarksdialog.cpp" line="84"/>
        <source>New bookmark</source>
        <translation>Nieuwe bladwijzer</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../execfiledialog.cpp" line="40"/>
        <source>This file &apos;%1&apos; seems to be a desktop entry.
What do you want to do with it?</source>
        <translation>‘%1’ lijkt een bureaubladsnelkoppeling te zijn.
Wat wilt u ermee doen?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="46"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>‘%1’ lijkt een uitvoerbaar script te zijn.
Wat wilt u ermee doen?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="51"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>‘%1’ is uitvoerbaar. Wilt u het uitvoeren?</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialog</name>
    <message>
        <location filename="../filedialog.cpp" line="115"/>
        <source>Go Back</source>
        <translation>Ga terug</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="116"/>
        <source>Alt+Left</source>
        <comment>Go Back</comment>
        <translation>Alt+Links</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="122"/>
        <source>Go Forward</source>
        <translation>Ga vooruit</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="123"/>
        <source>Alt+Right</source>
        <comment>Go Forward</comment>
        <translation>Alt+Rechts</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="130"/>
        <source>Reload</source>
        <translation>Herladen</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="131"/>
        <source>F5</source>
        <comment>Reload</comment>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="148"/>
        <source>Create Folder</source>
        <translation>Map maken</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="164"/>
        <source>Icon View</source>
        <translation>Pictogramweergave</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="168"/>
        <source>Thumbnail View</source>
        <translation>Miniatuurweergave</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="172"/>
        <source>Compact View</source>
        <translation>Compacte weergave</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="176"/>
        <source>Detailed List View</source>
        <translation>Uitgebreide lijstweergave</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="184"/>
        <source>Icon Sizes</source>
        <translation>Pictogramomvang</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="186"/>
        <source>Size of big icons:</source>
        <translation>Omvang van grote pictogrammen:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="193"/>
        <source>Size of small icons:</source>
        <translation>Omvang van kleine pictogrammen:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="200"/>
        <source>Size of thumbnails:</source>
        <translation>Minatuuromvang:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="216"/>
        <source>Show Hidden</source>
        <translation>Verborgen bestanden/mappen tonen</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="228"/>
        <source>Show Thumbnails</source>
        <translation>Miniaturen tonen</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="233"/>
        <source>Show File Tooltips</source>
        <translation>Hulpballonnen bij bestanden tonen</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="240"/>
        <source>Smooth Scrolling</source>
        <translation>Vloeiend schuiven</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="255"/>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="605"/>
        <location filename="../filedialog.cpp" line="1064"/>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="605"/>
        <source>Please select a file</source>
        <translation>Kies een bestand</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="681"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 bestaat al.
Wilt u het vervangen?</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1026"/>
        <source>Path &quot;%1&quot; does not exist</source>
        <translation>De locatie, ‘%1’, bestaat niet</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1040"/>
        <source>&quot;%1&quot; is not a directory</source>
        <translation>‘%1’ is geen map</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1050"/>
        <source>&quot;%1&quot; is not a file</source>
        <translation>‘%1’ is geen bestand</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1204"/>
        <location filename="../filedialog.cpp" line="1321"/>
        <source>&amp;Open</source>
        <translation>O&amp;penen</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1207"/>
        <location filename="../filedialog.cpp" line="1329"/>
        <source>&amp;Save</source>
        <translation>Op&amp;slaan</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1214"/>
        <source>All Files (*)</source>
        <translation>Alle bestanden (*)</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogHelper</name>
    <message>
        <location filename="../filedialoghelper.cpp" line="140"/>
        <source>Open File</source>
        <translation>Bestand openen</translation>
    </message>
    <message>
        <location filename="../filedialoghelper.cpp" line="141"/>
        <source>Save File</source>
        <translation>Bestand opslaan</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogIconSizeAction</name>
    <message>
        <location filename="../filedialog_p.h" line="40"/>
        <source> px</source>
        <translation> px</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../filemenu.cpp" line="86"/>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="419"/>
        <source>Many files</source>
        <translation>Veel bestanden</translation>
    </message>
    <message numerus="yes">
        <location filename="../filemenu.cpp" line="420"/>
        <source>Do you want to open these %1 files?</source>
        <translation>
            <numerusform>Wilt u %1 bestand openen?</numerusform>
            <numerusform>Wilt u %1 bestanden openen?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="188"/>
        <source>Create &amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="207"/>
        <source>&amp;Restore</source>
        <translation>Te&amp;rugzetten</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="217"/>
        <source>Cut</source>
        <translation>Knippen</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="221"/>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="225"/>
        <source>Paste</source>
        <translation>Plakken</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="229"/>
        <location filename="../filemenu.cpp" line="547"/>
        <source>&amp;Move to Trash</source>
        <translation>Verplaatsen naar &amp;prullenbak</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="289"/>
        <source>Mount</source>
        <translation>Aankoppelen</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="303"/>
        <source>Unmount</source>
        <translation>Ontkoppelen</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="317"/>
        <source>Eject</source>
        <translation>Uitwerpen</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="376"/>
        <source>Trust selected executables</source>
        <translation>Geselecteerde uitvoerbare bestanden vertrouwen</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="377"/>
        <source>Trust this executable</source>
        <translation>Uitvoerbaar bestand vertrouwen</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="482"/>
        <source>Output</source>
        <translation>Uitvoer</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="211"/>
        <location filename="../filemenu.cpp" line="547"/>
        <source>&amp;Delete</source>
        <translation>&amp;Wissen</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="233"/>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="90"/>
        <source>Open With...</source>
        <translation>Openen met…</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="181"/>
        <source>Other Applications</source>
        <translation>Andere programma&apos;s</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="338"/>
        <source>Extract to...</source>
        <translation>Uitpakken naar…</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="346"/>
        <source>Extract Here</source>
        <translation>Hier uitpakken</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="353"/>
        <source>Compress</source>
        <translation>Inpakken</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="362"/>
        <source>Properties</source>
        <translation>Eigenschappen</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../fileoperation.cpp" line="317"/>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="318"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>Sommige bestanden kunnen niet naar de prullenbak worden verplaatst, omdat de onderliggende bestandssystemen deze bewerking niet ondersteunen.
Wilt u ze in plaats daarvan permanent verwijderen?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="404"/>
        <location filename="../fileoperation.cpp" line="422"/>
        <source>Confirm</source>
        <translation>Bevestigen</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="405"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>
            <numerusform>Weet u zeker dat u het geselecteerde bestand wilt verwijderen?</numerusform>
            <numerusform>Weet u zeker dat u de geselecteerde bestanden wilt verwijderen?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="423"/>
        <source>Do you want to move the selected file(s) to trash can?</source>
        <translation>
            <numerusform>Weet u zeker dat u het geselecteerde bestand wilt verplaatsen naar de prullenbak?</numerusform>
            <numerusform>Weet u zeker dat u de geselecteerde bestanden wilt verplaatsen naar de prullenbak?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../fileoperationdialog.cpp" line="46"/>
        <source>Move Files</source>
        <translation>Bestanden verplaatsen</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="47"/>
        <source>Moving the following files to destination folder:</source>
        <translation>Verplaats de volgende bestanden naar de bestemming:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="50"/>
        <source>Copy Files</source>
        <translation>Bestanden kopiëren</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="51"/>
        <source>Copying the following files to destination folder:</source>
        <translation>Kopieer de volgende bestanden naar de bestemming:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="54"/>
        <source>Trash Files</source>
        <translation>Verplaatsen naar prullenbak</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="55"/>
        <source>Moving the following files to trash can:</source>
        <translation>Verplaats de volgende bestanden naar de prullenbak:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="58"/>
        <source>Delete Files</source>
        <translation>Bestanden verwijderen</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="59"/>
        <source>Deleting the following files:</source>
        <translation>Verwijder de volgende bestanden:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="64"/>
        <source>Create Symlinks</source>
        <translation>Snelkoppelingen maken</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="65"/>
        <source>Creating symlinks for the following files:</source>
        <translation>Maak snelkoppelingen voor de volgende bestanden:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="68"/>
        <source>Change Attributes</source>
        <translation>Eigenschappen aanpassen</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="69"/>
        <source>Changing attributes of the following files:</source>
        <translation>Pas de eigenschappen van de volgende bestanden aan:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="74"/>
        <source>Restore Trashed Files</source>
        <translation>Bestanden terugzetten</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="75"/>
        <source>Restoring the following files from trash can:</source>
        <translation>Herstel de volgende bestanden uit de prullenbak:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="149"/>
        <location filename="../fileoperationdialog.cpp" line="155"/>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../filepropsdialog.cpp" line="167"/>
        <source>View folder content</source>
        <translation>Mapinhoud tonen</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="168"/>
        <source>View and modify folder content</source>
        <translation>Mapinhoud tonen en aanpassen</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="172"/>
        <source>Read</source>
        <translation>Lezen</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="173"/>
        <source>Read and write</source>
        <translation>Lezen en schrijven</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="175"/>
        <source>Forbidden</source>
        <translation>Verboden</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="292"/>
        <source>Files of different types</source>
        <translation>Bestanden van verschillende soorten</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="315"/>
        <location filename="../filepropsdialog.cpp" line="322"/>
        <location filename="../filepropsdialog.cpp" line="329"/>
        <source>N/A</source>
        <translation>n/b</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="333"/>
        <source>Multiple Files</source>
        <translation>Meerdere bestanden</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="410"/>
        <source>%p% used</source>
        <translation>%p% gebruikt</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="411"/>
        <source>%1 Free of %2</source>
        <translation>%1/%2 vrij</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="457"/>
        <source>no file</source>
        <translation>geen bestand</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="459"/>
        <source>one file</source>
        <translation>één bestand</translation>
    </message>
    <message numerus="yes">
        <location filename="../filepropsdialog.cpp" line="461"/>
        <source>%Ln files</source>
        <translation>
            <numerusform>%Ln bestanden</numerusform>
            <numerusform>%Ln bestanden</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="495"/>
        <location filename="../filepropsdialog.cpp" line="540"/>
        <source>Select an icon</source>
        <translation>Kies een pictogram</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="497"/>
        <location filename="../filepropsdialog.cpp" line="542"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>Afbeeldingen (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="648"/>
        <source>Apply changes</source>
        <translation>Wijzigingen toepassen</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="649"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>Wilt u de wijzigingen toepassen op alle bestanden en onderliggende mappen?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../filesearchdialog.cpp" line="157"/>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="157"/>
        <source>You should add at least one directory to search.</source>
        <translation>U dient tenminste één te doorzoeken map toe te voegen.</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="164"/>
        <source>Select a folder</source>
        <translation>Kies een map</translation>
    </message>
</context>
<context>
    <name>Fm::FileTransferJob</name>
    <message>
        <location filename="../core/filetransferjob.cpp" line="486"/>
        <source>Cannot copy a directory into itself!</source>
        <translation>Kan map niet naar zichzelf kopiëren!</translation>
    </message>
    <message>
        <location filename="../core/filetransferjob.cpp" line="537"/>
        <source>Cannot create a link on non-native filesystem</source>
        <translation>Kan geen koppeling aanmaken op een niet-eigen bestandssysteem</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../foldermenu.cpp" line="58"/>
        <source>Empty Trash</source>
        <translation>Prullenbak legen</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="70"/>
        <source>Create &amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="75"/>
        <source>&amp;Paste</source>
        <translation>&amp;Plakken</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="89"/>
        <source>Select &amp;All</source>
        <translation>&amp;Alles selecteren</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="100"/>
        <source>Sorting</source>
        <translation>Sortering</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="105"/>
        <source>Show Hidden</source>
        <translation>Verborgen bestanden/mappen tonen</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="140"/>
        <source>Folder Pr&amp;operties</source>
        <translation>Map&amp;eigenschappen</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="183"/>
        <source>Output</source>
        <translation>Uitvoer</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="205"/>
        <source>By File Name</source>
        <translation>Op bestandnaam</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="206"/>
        <source>By Modification Time</source>
        <translation>Op wijzigingstijdstip</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="207"/>
        <source>By Creation Time</source>
        <translation>Op aanmaaktijdstip</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="210"/>
        <source>By Deletion Time</source>
        <translation>Op verwijdertijdstip</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="213"/>
        <source>By File Size</source>
        <translation>Op bestandsgrootte</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="214"/>
        <source>By File Type</source>
        <translation>Op bestandstype</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="215"/>
        <source>By File Owner</source>
        <translation>Op eigenaar</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="216"/>
        <source>By File Group</source>
        <translation>Op bestandsgroep</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="222"/>
        <source>Ascending</source>
        <translation>Oplopend</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="227"/>
        <source>Descending</source>
        <translation>Aflopend</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="244"/>
        <source>Folder First</source>
        <translation>Mappen bovenaan</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="252"/>
        <source>Hidden Last</source>
        <translation>Verborgen onderaan</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="260"/>
        <source>Case Sensitive</source>
        <translation>Hoofdlettergevoelig</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../foldermodel.cpp" line="306"/>
        <source>Location:</source>
        <translation>Locatie:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="310"/>
        <source>File type:</source>
        <translation>Bestandstype:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="315"/>
        <source>File size:</source>
        <translation>Bestandsgrootte:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="319"/>
        <source>Last modified:</source>
        <translation>Laatst gewijzigd:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="320"/>
        <source>Last accessed:</source>
        <translation>Laatst geopend:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="321"/>
        <source>N/A</source>
        <translation>n/b</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="323"/>
        <source>Created:</source>
        <translation>Aangemaakt op:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="328"/>
        <source>Owner:</source>
        <translation>Eigenaar:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="329"/>
        <source>Group:</source>
        <translation>Groep:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="396"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="399"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="402"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="405"/>
        <source>Modified</source>
        <translation>Gewijzigd</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="408"/>
        <source>Created</source>
        <translation>Aangemaakt</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="411"/>
        <source>Deleted</source>
        <translation>Verwijderd</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="414"/>
        <source>Owner</source>
        <translation>Eigenaar</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="417"/>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
</context>
<context>
    <name>Fm::FolderViewTreeView</name>
    <message>
        <location filename="../folderview.cpp" line="410"/>
        <source>Auto-resize columns</source>
        <translation>Kolommen automatisch inpassen</translation>
    </message>
    <message>
        <location filename="../folderview.cpp" line="427"/>
        <source>Visible Columns</source>
        <translation>Getoonde kolommen</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Vetgedrukt</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Cursief</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../mountoperationpassworddialog.cpp" line="42"/>
        <source>&amp;Connect</source>
        <translation>&amp;Verbinden</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../pathbar.cpp" line="123"/>
        <source>&amp;Edit Path</source>
        <translation>Locatie b&amp;ewerken</translation>
    </message>
    <message>
        <location filename="../pathbar.cpp" line="126"/>
        <source>&amp;Copy Path</source>
        <translation>Locatie &amp;kopiëren</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../placesmodel.cpp" line="46"/>
        <source>Places</source>
        <translation>Locaties</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="54"/>
        <source>Desktop</source>
        <translation>Bureaublad</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="227"/>
        <source>Trash</source>
        <translation>Prullenbak</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="60"/>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="68"/>
        <source>Applications</source>
        <translation>Programma&apos;s</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="77"/>
        <source>Network</source>
        <translation>Netwerk</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="81"/>
        <source>Devices</source>
        <translation>Apparaten</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="136"/>
        <source>Bookmarks</source>
        <translation>Bladwijzers</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../placesview.cpp" line="580"/>
        <source>Empty Trash</source>
        <translation>Prullenbak legen</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="563"/>
        <source>Open in New Tab</source>
        <translation>Openen op nieuw tabblad</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="567"/>
        <source>Open in New Window</source>
        <translation>Openen in nieuw venster</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="600"/>
        <location filename="../placesview.cpp" line="662"/>
        <source>Hide</source>
        <translation>Verbergen</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="617"/>
        <source>Move Bookmark Up</source>
        <translation>Bladwijzer omhoog verplaatsen</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="624"/>
        <source>Move Bookmark Down</source>
        <translation>Bladwijzer omlaag verplaatsen</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="629"/>
        <source>Rename Bookmark</source>
        <translation>Bladwijzernaam wijzigen</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="633"/>
        <source>Remove Bookmark</source>
        <translation>Bladwijzer verwijderen</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="643"/>
        <location filename="../placesview.cpp" line="676"/>
        <source>Unmount</source>
        <translation>Ontkoppelen</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="647"/>
        <source>Mount</source>
        <translation>Aankoppelen</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="653"/>
        <source>Eject</source>
        <translation>Uitwerpen</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="688"/>
        <source>Show All Entries</source>
        <translation>Alle items tonen</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../renamedialog.cpp" line="58"/>
        <location filename="../renamedialog.cpp" line="77"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>Type: %1
Omvang: %2
Gewijzigd: %3</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="64"/>
        <location filename="../renamedialog.cpp" line="83"/>
        <source>Type: %1
Modified: %2</source>
        <translation>Type: %1
Gewijzigd: %2</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="104"/>
        <source>&amp;Overwrite</source>
        <translation>Over&amp;schrijven</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="106"/>
        <source>&amp;Rename</source>
        <translation>&amp;Naam wijzigen</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="116"/>
        <source>&lt;p&gt;&lt;b&gt;The file cannot overwrite itself.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please select another name.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Het bestand kan niet zichzelf overschrijven.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Geef een andere naam op.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../sidepane.cpp" line="46"/>
        <source>Lists</source>
        <translation>Lijsten</translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="47"/>
        <source>Directory Tree</source>
        <translation>Boomweergave</translation>
    </message>
</context>
<context>
    <name>Fm::UntrashJob</name>
    <message>
        <location filename="../core/untrashjob.cpp" line="35"/>
        <source>Cannot untrash file &apos;%s&apos;: original path not known</source>
        <translation>Kan bestand ‘%s’ niet uit de prullenbak halen: oorspronkelijke locatie onbekend</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>Aankoppelen</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>&amp;Anoniem verbinden</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>Verbinden al&amp;s gebruiker:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="76"/>
        <source>&amp;Username:</source>
        <translation>Gebr&amp;uikersnaam:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="108"/>
        <source>&amp;Password:</source>
        <translation>&amp;Wachtwoord:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="89"/>
        <source>&amp;Domain:</source>
        <translation>&amp;Domein:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>Wachtwoord &amp;direct vergeten</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="137"/>
        <source>Session length is determined by password manager</source>
        <translation>De sessieduur wordt bepaald door de wachtwoordbeheerder</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="140"/>
        <source>Remember password for &amp;this session</source>
        <translation>Wachtwoord deze sessie on&amp;thouden</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="150"/>
        <source>Remember &amp;forever</source>
        <translation>Wachtwoord altijd ont&amp;houden</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../filelauncher.cpp" line="124"/>
        <location filename="../filepropsdialog.cpp" line="674"/>
        <location filename="../mountoperation.cpp" line="297"/>
        <location filename="../utilities.cpp" line="154"/>
        <location filename="../utilities.cpp" line="318"/>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="170"/>
        <source>Rename File</source>
        <translation>Bestandsnaam wijzigen</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="171"/>
        <source>Please enter a new name:</source>
        <translation>Voer een nieuwe naam in:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="230"/>
        <source>Create Folder</source>
        <translation>Map maken</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="235"/>
        <source>Please enter a new file name:</source>
        <translation>Voer een nieuwe bestandsnaam in:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="236"/>
        <source>New file</source>
        <translation>Nieuw bestand</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="240"/>
        <source>Please enter a new folder name:</source>
        <translation>Voer een nieuwe mapnaam in:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="241"/>
        <source>New folder</source>
        <translation>Nieuwe map</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="246"/>
        <source>Enter a name for the new %1:</source>
        <translation>Voer een naam in voor de/het nieuwe %1:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="231"/>
        <source>Create File</source>
        <translation>Bestand maken</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="692"/>
        <source>Custom Icon Error</source>
        <translation>Fout omtrent aangepast pictogram</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="41"/>
        <source>The path is not mounted.</source>
        <translation>De locatie is niet aangekoppeld.</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="319"/>
        <source>Invalid desktop entry file: &apos;%1&apos;</source>
        <translation>Ongeldig snelkoppelingsbestand: ‘%1’</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="355"/>
        <source>No default application is set to launch &apos;%1&apos;</source>
        <translation>Er is geen standaardprogramma ingesteld om ‘%1’ mee te openen</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="396"/>
        <source>Cannot set working directory to &apos;%1&apos;: %2</source>
        <translation>Kan werkmap niet instellen op ‘%1’: %2</translation>
    </message>
    <message>
        <location filename="../placesmodelitem.cpp" line="127"/>
        <source>Identifier: </source>
        <translation>Identificatie: </translation>
    </message>
    <message>
        <location filename="../foldermodelitem.cpp" line="61"/>
        <location filename="../foldermodelitem.cpp" line="74"/>
        <source>N/A</source>
        <translation>n/b</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>Bestandsvervanging bevestigen</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Er is al een bestand met dezelfde naam op deze locatie.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Wilt u het bestaande bestand vervangen?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="76"/>
        <source>with the following file?</source>
        <translation>door het volgende bestand?</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>&amp;Bestandsnaam:</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>Optie toepassen op alle bestaande bestanden</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>Bestanden zoeken</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>Naam/Locatie</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>Bestandsnaampatronen:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="44"/>
        <source>*</source>
        <translation>*</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="58"/>
        <source>Use regular expression</source>
        <translation>Reguliere uitdrukking gebruiken</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="71"/>
        <source>Places to Search:</source>
        <translation>Te doorzoeken locaties:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="84"/>
        <source>&amp;Add</source>
        <translation>&amp;Toevoegen</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="96"/>
        <source>&amp;Remove</source>
        <translation>Ve&amp;rwijderen</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="132"/>
        <source>Search for hidden files</source>
        <translation>Zoeken naar verborgen bestanden</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="143"/>
        <source>File Type</source>
        <translation>Bestandstype</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="149"/>
        <source>Only search for files of following types:</source>
        <translation>Alleen zoeken naar bestanden met de volgende types:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="155"/>
        <source>Text files</source>
        <translation>Tekstbestanden</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="162"/>
        <source>Image files</source>
        <translation>Afbeeldingsbestanden</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="169"/>
        <source>Audio files</source>
        <translation>Audiobestanden</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="176"/>
        <source>Video files</source>
        <translation>Videobestanden</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="183"/>
        <source>Documents</source>
        <translation>Documenten</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="190"/>
        <source>Folders</source>
        <translation>Mappen</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="214"/>
        <source>Content</source>
        <translation>Inhoud</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="220"/>
        <source>File contains:</source>
        <translation>Bestand bevat:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="240"/>
        <source>&amp;Use regular expression</source>
        <translation>Reguliere uitdrukking gebr&amp;uiken</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="267"/>
        <source>Properties</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="273"/>
        <source>File Size:</source>
        <translation>Bestandsgrootte:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="281"/>
        <source>Larger than:</source>
        <translation>Groter dan:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="302"/>
        <location filename="../filesearch.ui" line="346"/>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="307"/>
        <location filename="../filesearch.ui" line="351"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="312"/>
        <location filename="../filesearch.ui" line="356"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="317"/>
        <location filename="../filesearch.ui" line="361"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="325"/>
        <source>Smaller than:</source>
        <translation>Kleiner dan:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="51"/>
        <source>Case sensitive</source>
        <translation>Hoofdlettergevoelig</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="125"/>
        <source>Search in subdirectories</source>
        <translation>Onderliggende mappen doorzoeken</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="233"/>
        <source>Case sensiti&amp;ve</source>
        <translation>Hoofdletterge&amp;voelig</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="377"/>
        <source>Last Modified Time:</source>
        <translation>Laatst gewijzigd om:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="385"/>
        <source>Earlier than:</source>
        <translation>Vroeger dan:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="402"/>
        <source>Later than:</source>
        <translation>Later dan:</translation>
    </message>
</context>
</TS>
